@@ -242,6 +242,18 @@ DEFAULT_OPTS = {
         # non-CLI
         'default': os.path.join(constants.default_conf_dir, 'remove.conf')
     },
+    'tags_file': {
+        # non-CLI
+        'default': os.path.join(constants.default_conf_dir, 'tags.yaml')
+    },
+    'redaction_file': {
+        # non-CLI
+        'default': os.path.join(constants.default_conf_dir, 'file-redaction.yaml')
+    },
+    'content_redaction_file': {
+        # non-CLI
+        'default': os.path.join(constants.default_conf_dir, 'file-content-redaction.yaml')
+    },
     'reregister': {
         'default': False,
         'opt': ['--force-reregister'],
@@ -331,7 +343,7 @@ DEFAULT_OPTS = {
     'validate': {
         'default': False,
         'opt': ['--validate'],
-        'help': 'Validate remove.conf',
+        'help': 'Validate remove.conf and tags.yaml',
         'action': 'store_true'
     },
     'verbose': {
@@ -631,10 +643,6 @@ class InsightsConfig(object):
         if self.payload and not self.content_type:
             raise ValueError(
                 '--payload requires --content-type')
-        if not self.legacy_upload:
-            if self.group:
-                raise ValueError(
-                    '--group is not supported at this time.')
         if self.offline:
             if self.to_json:
                 raise ValueError('Cannot use --to-json in offline mode.')
