@@ -64,22 +64,12 @@ def pre_update(client, config):
     # validate the remove file
     if config.validate:
         try:
-            if validate_remove_file(config):
-                sys.exit(constants.sig_kill_ok)
-            else:
-                sys.exit(constants.sig_kill_bad)
+            validate_remove_file(config)
+            sys.exit(constants.sig_kill_ok)
         except RuntimeError as e:
             logger.error(e)
             sys.exit(constants.sig_kill_bad)
 
-    if os.path.isfile(config.remove_file):
-        if os.stat(config.remove_file).st_size != 0:
-            try:
-                validate_remove_file(config)
-            except RuntimeError as e:
-                logger.error(e)
-                sys.exit(constants.sig_kill_bad)
-
     # handle cron stuff
     if config.enable_schedule:
         # enable automatic scheduling
