@@ -15,13 +15,18 @@ from subprocess import Popen, PIPE, STDOUT
 
 import yaml
 try:
-    from yaml import CLoader as Loader, CDumper as Dumper
+    from yaml import CDumper as Dumper
 except ImportError:
-    from yaml import Loader, Dumper
+    from yaml import Dumper
 
 from .. import package_info
 from .constants import InsightsConstants as constants
-from .collection_rules import InsightsUploadConf
+from .collection_rules import InsightsUploadConf, load_yaml
+
+try:
+    from insights_client.constants import InsightsConstants as wrapper_constants
+except ImportError:
+    wrapper_constants = None
 
 logger = logging.getLogger(__name__)
 
@@ -171,7 +176,7 @@ def _expand_paths(path):
 
 def validate_remove_file(config):
     """
-    Validate the remove file
+    Validate the remove file and tags file
     """
     return InsightsUploadConf(config).validate()
 
@@ -228,16 +233,14 @@ def get_version_info():
     '''
     Get the insights client and core versions for archival
     '''
-    cmd = 'rpm -q --qf "%{VERSION}-%{RELEASE}" insights-client'
+    try:
+        client_version = wrapper_constants.version
+    except AttributeError:
+        # wrapper_constants is None or has no attribute "version"
+        client_version = None
     version_info = {}
     version_info['core_version'] = '%s-%s' % (package_info['VERSION'], package_info['RELEASE'])
-    rpm_proc = run_command_get_output(cmd)
-    if rpm_proc['status'] != 0:
-        # Unrecoverable error
-        logger.debug('Error occurred while running rpm -q. Details:\n%s' % rpm_proc['output'])
-        version_info['client_version'] = None
-    else:
-        version_info['client_version'] = rpm_proc['output']
+    version_info['client_version'] = client_version
     return version_info
 
 
@@ -315,7 +318,7 @@ def systemd_notify(pid):
         logger.debug('systemd-notify returned %s', proc.returncode)
 
 
-def get_tags(tags_file_path=os.path.join(constants.default_conf_dir, "tags.conf")):
+def get_tags(tags_file_path=constants.default_tags_file):
     '''
     Load tag data from the tags file.
 
@@ -323,17 +326,19 @@ def get_tags(tags_file_path=os.path.join(constants.default_conf_dir, "tags.conf"
     '''
     tags = None
 
-    try:
-        with open(tags_file_path) as f:
-            data = f.read()
-            tags = yaml.load(data, Loader=Loader)
-    except EnvironmentError as e:
-        logger.debug("tags file does not exist: %s", os.strerror(e.errno))
+    if os.path.isfile(tags_file_path):
+        try:
+            tags = load_yaml(tags_file_path)
+        except RuntimeError:
+            logger.error("Invalid YAML. Unable to load %s", tags_file_path)
+            return None
+    else:
+        logger.debug("%s does not exist", tags_file_path)
 
     return tags
 
 
-def write_tags(tags, tags_file_path=os.path.join(constants.default_conf_dir, "tags.conf")):
+def write_tags(tags, tags_file_path=constants.default_tags_file):
     """
     Writes tags to tags_file_path
 
@@ -346,3 +351,25 @@ def write_tags(tags, tags_file_path=os.path.join(constants.default_conf_dir, "ta
     with open(tags_file_path, mode="w") as f:
         data = yaml.dump(tags, Dumper=Dumper, default_flow_style=False)
         f.write(data)
+
+
+def migrate_tags():
+    '''
+    We initially released the tags feature with the tags file set as
+    tags.conf, but soon after switched it over to tags.yaml. There may be
+    installations out there with tags.conf files, so rename the files.
+    '''
+    tags_conf = os.path.join(constants.default_conf_dir, 'tags.conf')
+    tags_yaml = os.path.join(constants.default_conf_dir, 'tags.yaml')
+
+    if os.path.exists(tags_yaml):
+        # current default file exists, do nothing
+        return
+    if os.path.exists(tags_conf):
+        # old file exists and current does not
+        logger.info('Tags file %s detected. This filename is deprecated; please use %s. The file will be renamed automatically.',
+                    tags_conf, tags_yaml)
+        try:
+            os.rename(tags_conf, tags_yaml)
+        except OSError as e:
+            logger.error(e)
