@@ -93,6 +93,7 @@ class Specs(SpecSet):
     cpuinfo = RegistryPoint()
     cpupower_frequency_info = RegistryPoint()
     cpuset_cpus = RegistryPoint()
+    cron_daily_rhsmd = RegistryPoint(filterable=True)
     crypto_policies_config = RegistryPoint()
     crypto_policies_state_current = RegistryPoint()
     crypto_policies_opensshserver = RegistryPoint()
@@ -102,7 +103,6 @@ class Specs(SpecSet):
     date_iso = RegistryPoint()
     date = RegistryPoint()
     date_utc = RegistryPoint()
-    db2licm_l = RegistryPoint()
     dcbtool_gc_dcb = RegistryPoint(multi_output=True)
     df__alP = RegistryPoint()
     df__al = RegistryPoint()
@@ -134,6 +134,7 @@ class Specs(SpecSet):
     docker_storage = RegistryPoint()
     docker_storage_setup = RegistryPoint()
     docker_sysconfig = RegistryPoint()
+    dracut_kdump_capture_service = RegistryPoint()
     dumpe2fs_h = RegistryPoint(multi_output=True)
     engine_config_all = RegistryPoint()
     engine_log = RegistryPoint(filterable=True)
@@ -353,6 +354,7 @@ class Specs(SpecSet):
     mysqld_limits = RegistryPoint()
     named_checkconf_p = RegistryPoint(filterable=True)
     namespace = RegistryPoint()
+    ndctl_list_Ni = RegistryPoint()
     netconsole = RegistryPoint()
     netstat_agn = RegistryPoint()
     netstat_i = RegistryPoint()
