@@ -37,7 +37,6 @@ class InsightsArchiveSpecs(Specs):
     date = simple_file("insights_commands/date")
     date_iso = simple_file("insights_commands/date_--iso-8601_seconds")
     date_utc = simple_file("insights_commands/date_--utc")
-    db2licm_l = simple_file("insights_commands/db2licm_l")
     df__al = simple_file("insights_commands/df_-al")
     df__alP = simple_file("insights_commands/df_-alP")
     df__li = simple_file("insights_commands/df_-li")
@@ -171,6 +170,7 @@ class InsightsArchiveSpecs(Specs):
     mysqladmin_status = simple_file("insights_commands/mysqladmin_status")
     named_checkconf_p = simple_file("insights_commands/named-checkconf_-p")
     namespace = simple_file("insights_commands/ls_.var.run.netns")
+    ndctl_list_Ni = simple_file("insights_commands/ndctl_list_-Ni")
     netstat = simple_file("insights_commands/netstat_-neopa")
     netstat_agn = simple_file("insights_commands/netstat_-agn")
     netstat_i = simple_file("insights_commands/netstat_-i")
